@@ -25,8 +25,8 @@ use datafusion::arrow::record_batch::RecordBatch;
 use datafusion::dataframe::DataFrame;
 use datafusion::execution::options::CsvReadOptions;
 use datafusion::logical_plan::Expr;
-use datafusion::physical_plan::functions::BuiltinScalarFunction;
 use datafusion::prelude::{col, SessionContext};
+use datafusion_expr::BuiltinScalarFunction;
 use std::collections::{HashMap, HashSet};
 use std::fs::File;
 use std::io::Write;
