@@ -14,11 +14,12 @@ use chrono::{DateTime, TimeZone};
 use datafusion::arrow::array::{Array, ArrayRef, Int64Array};
 use datafusion::arrow::datatypes::DataType;
 use datafusion::logical_plan::{DFSchema, Expr, ExprSchemable};
-use datafusion::physical_plan::functions::{Signature, TypeSignature, Volatility};
 use datafusion::physical_plan::udf::ScalarUDF;
 use datafusion::physical_plan::ColumnarValue;
 use datafusion::scalar::ScalarValue;
-use datafusion_expr::{ReturnTypeFunction, ScalarFunctionImplementation};
+use datafusion_expr::{
+    ReturnTypeFunction, ScalarFunctionImplementation, Signature, TypeSignature, Volatility,
+};
 use std::sync::Arc;
 use vegafusion_core::error::{Result, ResultWithContext};
 
