@@ -27,8 +27,8 @@ use crate::expression::compiler::config::CompilationConfig;
 use crate::expression::compiler::utils::cast_to;
 use datafusion::arrow::datatypes::DataType;
 use datafusion::logical_plan::{DFSchema, Expr};
-use datafusion::physical_plan::functions::BuiltinScalarFunction;
 use datafusion::physical_plan::udf::ScalarUDF;
+use datafusion_expr::BuiltinScalarFunction;
 use std::collections::HashMap;
 use std::ops::Deref;
 use std::str::FromStr;
@@ -42,7 +42,10 @@ use vegafusion_core::proto::gen::expression::{
 use crate::expression::compiler::builtin_functions::data::data_fn::data_fn;
 use crate::expression::compiler::builtin_functions::data::vl_selection_resolve::vl_selection_resolve_fn;
 use crate::expression::compiler::builtin_functions::data::vl_selection_test::vl_selection_test_fn;
-use crate::expression::compiler::builtin_functions::date_time::time::make_time_udf;
+use crate::expression::compiler::builtin_functions::date_time::date_format::{
+    time_format_fn, utc_format_fn,
+};
+use crate::expression::compiler::builtin_functions::date_time::time::time_fn;
 use crate::expression::compiler::builtin_functions::type_checking::isdate::is_date_fn;
 use crate::expression::compiler::builtin_functions::type_coercion::to_boolean::to_boolean_transform;
 use crate::expression::compiler::builtin_functions::type_coercion::to_number::to_number_transform;
@@ -398,10 +401,15 @@ pub fn default_callables() -> HashMap<String, VegaFusionCallable> {
     );
     callables.insert(
         "time".to_string(),
-        VegaFusionCallable::ScalarUDF {
-            udf: make_time_udf(),
-            cast: None,
-        },
+        VegaFusionCallable::LocalTransform(Arc::new(time_fn)),
+    );
+    callables.insert(
+        "timeFormat".to_string(),
+        VegaFusionCallable::LocalTransform(Arc::new(time_format_fn)),
+    );
+    callables.insert(
+        "utcFormat".to_string(),
+        VegaFusionCallable::LocalTransform(Arc::new(utc_format_fn)),
     );
 
     // coercion
